==> gulid-0.0.3.tar: src/examples@example2.erl <==
-module(examples@example2).
-compile([no_auto_import, nowarn_unused_vars, nowarn_unused_function, nowarn_nomatch]).

-export([main/0]).

-file("/Users/svava/Projects/Gleam/ulid/src/examples/example2.gleam", 58).
-spec from_codepoints(list(integer())) -> binary().
from_codepoints(Code_points) ->
    _pipe = Code_points,
    _pipe@1 = gleam@list:map(_pipe, fun gleam@string:utf_codepoint/1),
    _pipe@2 = gleam@list:map(
        _pipe@1,
        fun(Res) ->
            _assert_subject = gleam@string:utf_codepoint(97),
            {ok, Default_codepoint} = case _assert_subject of
                {ok, _} -> _assert_subject;
                _assert_fail ->
                    erlang:error(#{gleam_error => let_assert,
                                message => <<"Pattern match failed, no pattern matched the value."/utf8>>,
                                value => _assert_fail,
                                module => <<"examples/example2"/utf8>>,
                                function => <<"from_codepoints"/utf8>>,
                                line => 62})
            end,
            gleam@result:unwrap(Res, Default_codepoint)
        end
    ),
    gleam_stdlib:utf_codepoint_list_to_string(_pipe@2).

-file("/Users/svava/Projects/Gleam/ulid/src/examples/example2.gleam", 12).
-spec main() -> bitstring().
main() ->
    To_string = gulid:to_string_function(),
    Ulid = gulid:from_parts(
        os:system_time(millisecond),
        gleam@int:random(99999999999)
    ),
    gleam@io:println(
        <<"My ulid made from spare parts: "/utf8, (To_string(Ulid))/binary>>
    ),
    gleam@io:debug(Ulid),
    {Timestamp, Random} = gulid:to_parts(Ulid),
    gleam@io:println(
        <<"Now, extracted its constituent timestamp and random:"/utf8>>
    ),
    gleam@io:println(
        <<"\tTime: "/utf8,
            (begin
                _pipe = calendar:system_time_to_rfc3339(Timestamp div 1000),
                from_codepoints(_pipe)
            end)/binary>>
    ),
    gleam@io:println(
        <<"\tRandom: "/utf8, (gleam@int:to_string(Random))/binary>>
    ),
    Same_ulid = gulid:from_tuple({Timestamp, Random}),
    gleam@io:println(
        <<"Now, we reconstruct a new ULID back from the earlier extracted components: "/utf8,
            (To_string(Same_ulid))/binary>>
    ),
    gleam@io:println(
        <<"Same ulids? "/utf8,
            ((gleam@bool:to_string(Same_ulid =:= Ulid)))/binary>>
    ),
    _assert_subject = begin
        _pipe@1 = <<(os:system_time(millisecond)):48/big,
            (gleam@int:random(9999999999)):80/big>>,
        gulid:from_bitarray(_pipe@1)
    end,
    {ok, Bin_ulid} = case _assert_subject of
        {ok, _} -> _assert_subject;
        _assert_fail ->
            erlang:error(#{gleam_error => let_assert,
                        message => <<"Pattern match failed, no pattern matched the value."/utf8>>,
                        value => _assert_fail,
                        module => <<"examples/example2"/utf8>>,
                        function => <<"main"/utf8>>,
                        line => 39})
    end,
    gleam@io:println(<<"Ulid from a bitarray: "/utf8>>),
    gleam@io:debug(Bin_ulid),
    gleam@io:println(<<"Ulid to binary: "/utf8>>),
    _pipe@2 = Bin_ulid,
    _pipe@3 = gulid:to_bitarray(_pipe@2),
    gleam@io:debug(_pipe@3).

==> gulid-0.0.5.tar: src/examples@example2.erl <==
-module(examples@example2).
-compile([no_auto_import, nowarn_unused_vars, nowarn_unused_function, nowarn_nomatch]).

-export([main/0]).

-file("/Users/svava/Projects/Gleam/ulid/src/examples/example2.gleam", 58).
-spec from_codepoints(list(integer())) -> binary().
from_codepoints(Code_points) ->
    _pipe = Code_points,
    _pipe@1 = gleam@list:map(_pipe, fun gleam@string:utf_codepoint/1),
    _pipe@2 = gleam@list:map(
        _pipe@1,
        fun(Res) ->
            _assert_subject = gleam@string:utf_codepoint(97),
            {ok, Default_codepoint} = case _assert_subject of
                {ok, _} -> _assert_subject;
                _assert_fail ->
                    erlang:error(#{gleam_error => let_assert,
                                message => <<"Pattern match failed, no pattern matched the value."/utf8>>,
                                value => _assert_fail,
                                module => <<"examples/example2"/utf8>>,
                                function => <<"from_codepoints"/utf8>>,
                                line => 62})
            end,
            gleam@result:unwrap(Res, Default_codepoint)
        end
    ),
    gleam_stdlib:utf_codepoint_list_to_string(_pipe@2).

-file("/Users/svava/Projects/Gleam/ulid/src/examples/example2.gleam", 12).
-spec main() -> bitstring().
main() ->
    To_string = gulid:to_string_function(),
    Ulid = gulid:from_parts(
        os:system_time(millisecond),
        gleam@int:random(99999999999)
    ),
    gleam_stdlib:println(
        <<"My ulid made from spare parts: "/utf8, (To_string(Ulid))/binary>>
    ),
    gleam@io:debug(Ulid),
    {Timestamp, Random} = gulid:to_parts(Ulid),
    gleam_stdlib:println(
        <<"Now, extracted its constituent timestamp and random:"/utf8>>
    ),
    gleam_stdlib:println(
        <<"\tTime: "/utf8,
            (begin
                _pipe = calendar:system_time_to_rfc3339(Timestamp div 1000),
                from_codepoints(_pipe)
            end)/binary>>
    ),
    gleam_stdlib:println(
        <<"\tRandom: "/utf8, (erlang:integer_to_binary(Random))/binary>>
    ),
    Same_ulid = gulid:from_tuple({Timestamp, Random}),
    gleam_stdlib:println(
        <<"Now, we reconstruct a new ULID back from the earlier extracted components: "/utf8,
            (To_string(Same_ulid))/binary>>
    ),
    gleam_stdlib:println(
        <<"Same ulids? "/utf8,
            ((gleam@bool:to_string(Same_ulid =:= Ulid)))/binary>>
    ),
    _assert_subject = begin
        _pipe@1 = <<(os:system_time(millisecond)):48/big,
            (gleam@int:random(9999999999)):80/big>>,
        gulid:from_bitarray(_pipe@1)
    end,
    {ok, Bin_ulid} = case _assert_subject of
        {ok, _} -> _assert_subject;
        _assert_fail ->
            erlang:error(#{gleam_error => let_assert,
                        message => <<"Pattern match failed, no pattern matched the value."/utf8>>,
                        value => _assert_fail,
                        module => <<"examples/example2"/utf8>>,
                        function => <<"main"/utf8>>,
                        line => 39})
    end,
    gleam_stdlib:println(<<"Ulid from a bitarray: "/utf8>>),
    gleam@io:debug(Bin_ulid),
    gleam_stdlib:println(<<"Ulid to binary: "/utf8>>),
    _pipe@2 = Bin_ulid,
    _pipe@3 = gulid:to_bitarray(_pipe@2),
    gleam@io:debug(_pipe@3).
